==> spip_4.1.7+dfsg.orig.tar.xz: plugins-dist/mediabox/lang/mediabox_de.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mediabox?lang_cible=de
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_reinitialiser' => 'Neu starten',
	'boxstr_close' => 'Schließen',
	'boxstr_current' => '@current@/@total@',
	'boxstr_dialog_title_default' => 'Dialogbox',
	'boxstr_dialog_title_medias' => 'Medienanzeige',
	'boxstr_loading' => 'Lädt…',
	'boxstr_next' => 'Weiter',
	'boxstr_press_escape_to_close' => 'Zum Schließen ’Esc’ drücken',
	'boxstr_previous' => 'Zurück',
	'boxstr_slideshowStart' => 'Diaschau',
	'boxstr_slideshowStop' => 'Stop',
	'boxstr_zoom' => 'Zoom',

	// E
	'explication_selecteur' => 'Geben sie hier CSS- bzw. erweiterten jQuery-Selektor an.',
	'explication_selecteur_galerie' => 'Geben sie den Selektor der Elemente an, die in der Galerie erscheinen sollen. (CSS bzw. jQuery Ausdruck)',
	'explication_splash_url' => 'Geben sie den URL des Mediums an, das einem Besucher beim ersten Besuch der Website automatisch in einem Kasten angezeigt werden soll.',
	'explication_traiter_toutes_images' => 'Alle Bilder in einem Kasten anzeigen?',

	// I
	'info_box_lity_nom_skin__simple_dark' => 'Standard Schwarz',
	'info_box_lity_nom_skin__simple_white' => 'Standard Hell',
	'info_box_lity_nom_skin_fancybox' => 'Stil Fancybox',
	'info_box_lity_nom_skin_thickbox' => 'Stil Thickbox',

	// L
	'label_active' => 'Mediabox für den öffentlichen Bereich aktivieren',
	'label_apparence' => 'Aussehen',
	'label_aucun_style' => 'Kein Standarddesign verwenden',
	'label_choix_transition_elastic' => 'Elastisch',
	'label_choix_transition_fade' => 'Überblendung',
	'label_choix_transition_none' => 'Kein Übergangseffekt',
	'label_defaultcaptionstate' => 'Bildlegende',
	'label_defaultcaptionstate_expanded' => 'Komplett',
	'label_defaultcaptionstate_min' => 'Kurzfassung',
	'label_maxheight' => 'Maximalhöhe (% oder px)',
	'label_maxwidth' => 'Maximalbreite (% oder px)',
	'label_minheight' => 'Minimalhöhe (% oder px)',
	'label_minwidth' => 'Minimalbreite (% oder px)',
	'label_opacite' => 'Transparenz des Hintergrunds',
	'label_selecteur_commun' => 'Allgemein',
	'label_selecteur_galerie' => 'Als Galerie',
	'label_skin' => 'Skin',
	'label_slideshow_speed' => 'Anzeigedauer der Diaschau-Bilder (ms)',
	'label_speed' => 'Dauer des Übergangseffekts (ms)',
	'label_splash' => 'Splash Box',
	'label_splash_height' => 'Höhe (% oder px)',
	'label_splash_url' => 'URL anzeigen',
	'label_splash_width' => 'Breite (% oder px)',
	'label_traiter_toutes_images' => 'Bilder',
	'label_transition' => 'Übergang zwischen zwei Elementen',

	// T
	'titre_menu_box' => 'Multimedia-Box',
	'titre_page_configurer_box' => 'Konfiguration der Multimedia-Box'
);

==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/mediabox/lang/mediabox_de.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mediabox?lang_cible=de
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_reinitialiser' => 'Zurücksetzen',
	'boxstr_close' => 'Schließen',
	'boxstr_current' => '@current@/@total@',
	'boxstr_dialog_title_default' => 'Dialogbox',
	'boxstr_dialog_title_medias' => 'Medienanzeige',
	'boxstr_loading' => 'Lädt…',
	'boxstr_next' => 'Weiter',
	'boxstr_press_escape_to_close' => 'Zum Schließen ’Esc’ drücken',
	'boxstr_previous' => 'Zurück',
	'boxstr_slideshowStart' => 'Diaschau',
	'boxstr_slideshowStop' => 'Stop',
	'boxstr_zoom' => 'Zoom',

	// E
	'explication_selecteur' => 'Geben sie hier CSS- bzw. erweiterten jQuery-Selektor an.',
	'explication_selecteur_galerie' => 'Geben sie den Selektor der Elemente an, die in der Galerie erscheinen sollen. (CSS bzw. jQuery Ausdruck)',
	'explication_splash_url' => 'Geben sie den URL des Mediums an, das einem Besucher beim ersten Besuch der Website automatisch in einem Kasten angezeigt werden soll.',
	'explication_traiter_toutes_images' => 'Alle Bilder in einem Kasten anzeigen?',

	// I
	'info_box_lity_nom_skin__simple_dark' => 'Standard Schwarz',
	'info_box_lity_nom_skin__simple_white' => 'Standard Hell',
	'info_box_lity_nom_skin_fancybox' => 'Stil Fancybox',
	'info_box_lity_nom_skin_thickbox' => 'Stil Thickbox',

	// L
	'label_active' => 'Mediabox für den öffentlichen Bereich aktivieren',
	'label_apparence' => 'Aussehen',
	'label_aucun_style' => 'Kein Standarddesign verwenden',
	'label_choix_transition_elastic' => 'Elastisch',
	'label_choix_transition_fade' => 'Überblendung',
	'label_choix_transition_none' => 'Kein Übergangseffekt',
	'label_defaultcaptionstate' => 'Bildlegende',
	'label_defaultcaptionstate_expanded' => 'Komplett',
	'label_defaultcaptionstate_min' => 'Kurzfassung',
	'label_maxheight' => 'Maximalhöhe (% oder px)',
	'label_maxwidth' => 'Maximalbreite (% oder px)',
	'label_minheight' => 'Minimalhöhe (% oder px)',
	'label_minwidth' => 'Minimalbreite (% oder px)',
	'label_opacite' => 'Transparenz des Hintergrunds',
	'label_selecteur_commun' => 'Allgemein',
	'label_selecteur_galerie' => 'Als Galerie',
	'label_skin' => 'Skin',
	'label_slideshow_speed' => 'Anzeigedauer der Diaschau-Bilder (ms)',
	'label_speed' => 'Dauer des Übergangseffekts (ms)',
	'label_splash' => 'Splash Box',
	'label_splash_height' => 'Höhe (% oder px)',
	'label_splash_url' => 'URL anzeigen',
	'label_splash_width' => 'Breite (% oder px)',
	'label_traiter_toutes_images' => 'Bilder',
	'label_transition' => 'Übergang zwischen zwei Elementen',

	// T
	'titre_menu_box' => 'Multimedia-Box',
	'titre_page_configurer_box' => 'Konfiguration der Multimedia-Box'
);
